%% LaTeX template class for technical report
%% for subject NRP in Czech Technical University in Prague (CTU)
%%
%% (c) 2008 Vit Zyka
%%
%% History:
%% 0.1 2008-09-21 new
%% 0.2 2008-11-12 href for email, unicode in hyperref; tolerance; microtype; cmap
%%   \texorpdfstring

\typeout{Class nrp-report v0.2, 2008-11-12, Vit Zyka}

%% Options...
\newif\ifCzech

\DeclareOption{czech}{\Czechtrue}
\ProcessOptions

\LoadClass[a4paper,normalheadings]{scrartcl}

%% Dimensions...
\setlength{\columnsep}{10mm}

\renewcommand{\topfraction}{0.9}
\renewcommand{\bottomfraction}{0.9}
\renewcommand{\dbltopfraction}{0.9}
\renewcommand{\textfraction}{0}
\setcounter{topnumber}{4}
\setcounter{bottomnumber}{4}
\setcounter{totalnumber}{4}
\setcounter{dbltopnumber}{4}

\tolerance=300

%% Packages...
\RequirePackage{ifpdf}
\ifCzech
  \RequirePackage[czech]{babel}
\fi
\RequirePackage{lmodern}
\RequirePackage{cmap}
\usepackage[T1]{fontenc}
\usepackage[left=15mm,right=15mm,top=18mm,bottom=20mm,footskip=10mm]{geometry}
\ifpdf
  \RequirePackage[pdftex]{graphicx}
  \RequirePackage[pdftex]{color}
\else
  \RequirePackage{graphicx}
  \RequirePackage{color}
\fi
\RequirePackage[pdfpagemode=UseNone,pdfborder=0 0 0,unicode]{hyperref}
\RequirePackage{mflogo}
\RequirePackage{natbib}
\RequirePackage{microtype}

%% Title...
\newtoks\NRPemail        \def\email#1{\NRPemail={#1}}
\newtoks\NRPaffiliation  \def\affiliation#1{\NRPaffiliation={#1}}

\def\affiliationFont{\normalfont\fontsize{12pt}{14pt}\selectfont}

\AtBeginDocument{%
  \expandafter\author\expandafter{%
    \@author\\[4pt]\affiliationFont
    \def\\{\crcr\affiliationFont}\the\NRPaffiliation\\
    \href{mailto:\the\NRPemail}{\affiliationFont\the\NRPemail}}%
  \expandafter\date\expandafter{\expandafter\affiliationFont\@date}%
}

\let\maketitleOrig=\maketitle
\def\maketitle{\@ifnextchar[{\domaketitle}{\domaketitle[]}}
\def\domaketitle[#1]{%
  \twocolumn[\vskip-1.5cm\maketitleOrig\begin{quotation}#1\end{quotation}\bigskip]%
}

%% Bibliography...
\bibliographystyle{plain}

%% Misc...
\def\CONTEXT{\texorpdfstring{Con\kern-.1em\TeX{}t}{ConTeXt}}
\def\MetaPost{\texorpdfstring{\MP}{MetaPost}}

\endinput

%% End of file `nrp-report.cls'
